@@ -65,13 +65,26 @@ REST_API_VERSION_HISTORY = """
             'migration_get_progress', 'migration_complete' APIs, renamed
             'migrate_share' to 'migration_start' and added notify parameter
              to 'migration_start'.
+    * 2.16 - Add user_id in share show/create/manage API.
+    * 2.17 - Added project_id and user_id fields to the JSON response of
+             snapshot show/create/manage API.
+    * 2.18 - Add gateway to the JSON response of share network show API.
+    * 2.19 - Share snapshot instances admin APIs
+            (list/show/detail/reset-status).
+    * 2.20 - Add MTU to the JSON response of share network show API.
+    * 2.21 - Add access_key to the response of access_list API.
+    * 2.22 - Updated migration_start API with 'preserve-metadata', 'writable',
+            'nondisruptive' and 'new_share_network_id' parameters, renamed
+            'force_host_copy' to 'force_host_assisted_migration', removed
+            'notify' parameter and removed previous migrate_share API support.
+            Updated reset_task_state API to accept 'None' value.
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # the minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.15"
+_MAX_API_VERSION = "2.22"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
