@@ -22,6 +22,7 @@ class ViewBuilder(common.ViewBuilder):
     _collection_name = 'snapshots'
     _detail_version_modifiers = [
         "add_provider_location_field",
+        "add_project_and_user_ids",
     ]
 
     def summary_list(self, request, snapshots):
@@ -57,17 +58,21 @@ class ViewBuilder(common.ViewBuilder):
             'links': self._get_links(request, snapshot['id']),
         }
 
-        # NOTE(xyang): Only retrieve provider_location for admin.
-        context = request.environ['manila.context']
-        if context.is_admin:
-            self.update_versioned_resource_dict(request, snapshot_dict,
-                                                snapshot)
+        self.update_versioned_resource_dict(request, snapshot_dict, snapshot)
 
         return {'snapshot': snapshot_dict}
 
     @common.ViewBuilder.versioned_method("2.12")
-    def add_provider_location_field(self, snapshot_dict, snapshot):
-        snapshot_dict['provider_location'] = snapshot.get('provider_location')
+    def add_provider_location_field(self, context, snapshot_dict, snapshot):
+        # NOTE(xyang): Only retrieve provider_location for admin.
+        if context.is_admin:
+            snapshot_dict['provider_location'] = snapshot.get(
+                'provider_location')
+
+    @common.ViewBuilder.versioned_method("2.17")
+    def add_project_and_user_ids(self, context, snapshot_dict, snapshot):
+        snapshot_dict['user_id'] = snapshot.get('user_id')
+        snapshot_dict['project_id'] = snapshot.get('project_id')
 
     def _list_view(self, func, request, snapshots):
         """Provide a view for a list of share snapshots."""
