@@ -167,7 +167,7 @@ class ShellCommands(object):
 
     @args('--path', required=True, help='Script path')
     def script(self, path):
-        """Runs the script from the specifed path with flags set properly.
+        """Runs the script from the specified path with flags set properly.
 
         arguments: path
         """
