@@ -60,6 +60,7 @@ CONF.register_cli_opts(debug_opts)
 global_opts = [
     cfg.StrOpt('my_ip',
                default=netutils.get_my_ipv4(),
+               sample_default='<your_ip>',
                help='IP address of this host.'),
     cfg.StrOpt('scheduler_topic',
                default='manila-scheduler',
@@ -70,16 +71,6 @@ global_opts = [
     cfg.StrOpt('data_topic',
                default='manila-data',
                help='The topic data nodes listen on.'),
-    cfg.BoolOpt('enable_v1_api',
-                default=False,
-                help=_('Deploy v1 of the Manila API. This option is '
-                       'deprecated, is not used, and will be removed '
-                       'in a future release.')),
-    cfg.BoolOpt('enable_v2_api',
-                default=False,
-                help=_('Deploy v2 of the Manila API. This option is '
-                       'deprecated, is not used, and will be removed '
-                       'in a future release.')),
     cfg.BoolOpt('api_rate_limit',
                 default=True,
                 help='Whether to rate limit the API.'),
@@ -118,6 +109,7 @@ global_opts = [
                help='Full class name for the data manager.'),
     cfg.StrOpt('host',
                default=socket.gethostname(),
+               sample_default='<your_hostname>',
                help='Name of this node.  This can be an opaque identifier.  '
                     'It is not necessarily a hostname, FQDN, or IP address.'),
     # NOTE(vish): default to nova for compatibility with nova installs
@@ -170,7 +162,7 @@ CONF.register_opts(global_opts)
 
 
 def verify_share_protocols():
-    """Perfom verification of 'enabled_share_protocols'."""
+    """Perform verification of 'enabled_share_protocols'."""
     msg = None
     supported_protocols = constants.SUPPORTED_SHARE_PROTOCOLS
     data = dict(supported=', '.join(supported_protocols))
