@@ -46,13 +46,15 @@ host_manager_opts = [
                     'CapacityFilter',
                     'CapabilitiesFilter',
                     'ConsistencyGroupFilter',
+                    'DriverFilter',
                     'ShareReplicationFilter',
                 ],
                 help='Which filter class names to use for filtering hosts '
                      'when not specified in the request.'),
     cfg.ListOpt('scheduler_default_weighers',
                 default=[
-                    'CapacityWeigher'
+                    'CapacityWeigher',
+                    'GoodnessWeigher',
                 ],
                 help='Which weigher class names to use for weighing hosts.')
 ]
@@ -66,6 +68,7 @@ LOG = log.getLogger(__name__)
 
 class ReadOnlyDict(IterableUserDict):
     """A read-only dict."""
+
     def __init__(self, source=None):
         self.data = {}
         self.update(source)
@@ -145,50 +148,52 @@ class HostState(object):
             service = {}
         self.service = ReadOnlyDict(service)
 
-    def update_from_share_capability(self, capability, service=None):
+    def update_from_share_capability(
+            self, capability, service=None, context=None):
         """Update information about a host from its share_node info.
 
         'capability' is the status info reported by share backend, a typical
-        capability looks like this:
+        capability looks like this::
 
-        capability = {
-            'share_backend_name': 'Local NFS',    #\
-            'vendor_name': 'OpenStack',           #  backend level
-            'driver_version': '1.0',              #  mandatory/fixed
-            'storage_protocol': 'NFS',            #/ stats&capabilities
+            capability = {
+                'share_backend_name': 'Local NFS',    #\
+                'vendor_name': 'OpenStack',           #  backend level
+                'driver_version': '1.0',              #  mandatory/fixed
+                'storage_protocol': 'NFS',            #/ stats&capabilities
 
-            'active_shares': 10,                  #\
-            'IOPS_provisioned': 30000,            #  optional custom
-            'fancy_capability_1': 'eat',          #  stats & capabilities
-            'fancy_capability_2': 'drink',        #/
+                'active_shares': 10,                  #\
+                'IOPS_provisioned': 30000,            #  optional custom
+                'fancy_capability_1': 'eat',          #  stats & capabilities
+                'fancy_capability_2': 'drink',        #/
 
-            'pools': [
-                {'pool_name': '1st pool',         #\
-                 'total_capacity_gb': 500,        #  mandatory stats for
-                 'free_capacity_gb': 230,         #  pools
-                 'allocated_capacity_gb': 270,    # |
-                 'qos': 'False',                  # |
-                 'reserved_percentage': 0,        #/
+                'pools':[
+                  {
+                     'pool_name': '1st pool',         #\
+                     'total_capacity_gb': 500,        #  mandatory stats
+                     'free_capacity_gb': 230,         #   for pools
+                     'allocated_capacity_gb': 270,    # |
+                     'qos': 'False',                  # |
+                     'reserved_percentage': 0,        #/
 
-                 'dying_disks': 100,              #\
-                 'super_hero_1': 'spider-man',    #  optional custom
-                 'super_hero_2': 'flash',         #  stats & capabilities
-                 'super_hero_3': 'neoncat'        #/
-                 },
-                {'pool_name': '2nd pool',
-                 'total_capacity_gb': 1024,
-                 'free_capacity_gb': 1024,
-                 'allocated_capacity_gb': 0,
-                 'qos': 'False',
-                 'reserved_percentage': 0,
+                     'dying_disks': 100,              #\
+                     'super_hero_1': 'spider-man',    #  optional custom
+                     'super_hero_2': 'flash',         #  stats &
+                     'super_hero_3': 'neoncat',       #  capabilities
+                     'super_hero_4': 'green lantern', #/
+                   },
+                  {
+                     'pool_name': '2nd pool',
+                     'total_capacity_gb': 1024,
+                     'free_capacity_gb': 1024,
+                     'allocated_capacity_gb': 0,
+                     'qos': 'False',
+                     'reserved_percentage': 0,
 
-                 'dying_disks': 200,
-                 'super_hero_1': 'superman',
-                 'super_hero_2': ' ',
-                 'super_hero_2': 'Hulk',
-                 }
-            ]
-        }
+                     'dying_disks': 200,
+                     'super_hero_1': 'superman',
+                     'super_hero_2': 'Hulk',
+                  }]
+            }
         """
         self.update_capabilities(capability, service)
 
@@ -200,9 +205,9 @@ class HostState(object):
             self.update_backend(capability)
 
             # Update pool level info
-            self.update_pools(capability, service)
+            self.update_pools(capability, service, context=context)
 
-    def update_pools(self, capability, service):
+    def update_pools(self, capability, service, context=None):
         """Update storage pools information from backend reported info."""
         if not capability:
             return
@@ -220,7 +225,8 @@ class HostState(object):
                     # Add new pool
                     cur_pool = PoolState(self.host, pool_cap, pool_name)
                     self.pools[pool_name] = cur_pool
-                cur_pool.update_from_share_capability(pool_cap, service)
+                cur_pool.update_from_share_capability(
+                    pool_cap, service, context=context)
 
                 active_pools.add(pool_name)
         elif pools is None:
@@ -247,7 +253,8 @@ class HostState(object):
                     self._append_backend_info(capability)
                     self.pools[pool_name] = single_pool
 
-            single_pool.update_from_share_capability(capability, service)
+            single_pool.update_from_share_capability(
+                capability, service, context=context)
             active_pools.add(pool_name)
 
         # Remove non-active pools from self.pools
@@ -338,6 +345,7 @@ class HostState(object):
 
 
 class PoolState(HostState):
+
     def __init__(self, host, capabilities, pool_name):
         new_host = share_utils.append_host(host, pool_name)
         super(PoolState, self).__init__(new_host, capabilities)
@@ -345,7 +353,20 @@ class PoolState(HostState):
         # No pools in pool
         self.pools = None
 
-    def update_from_share_capability(self, capability, service=None):
+    def _estimate_provisioned_capacity(self, host_name, context=None):
+        """Estimate provisioned capacity from share sizes on backend."""
+        provisioned_capacity = 0
+
+        instances = db.share_instances_get_all_by_host(
+            context, host_name, with_share_data=True)
+
+        for instance in instances:
+            # Size of share instance that's still being created, will be None.
+            provisioned_capacity += instance['size'] or 0
+        return provisioned_capacity
+
+    def update_from_share_capability(
+            self, capability, service=None, context=None):
         """Update information about a pool from its share_node info."""
         self.update_capabilities(capability, service)
         if capability:
@@ -363,10 +384,15 @@ class PoolState(HostState):
             # capacity of all the shares created on a backend, which is
             # greater than or equal to allocated_capacity_gb, which is the
             # apparent total capacity of all the shares created on a backend
-            # in Manila. Using allocated_capacity_gb as the default of
-            # provisioned_capacity_gb if it is not set.
+            # in Manila.
+            # NOTE(nidhimittalhada): If 'provisioned_capacity_gb' is not set,
+            # then calculating 'provisioned_capacity_gb' from share sizes
+            # on host, as per information available in manila database.
             self.provisioned_capacity_gb = capability.get(
-                'provisioned_capacity_gb', self.allocated_capacity_gb)
+                'provisioned_capacity_gb') or (
+                self._estimate_provisioned_capacity(self.host,
+                                                    context=context))
+
             self.max_over_subscription_ratio = capability.get(
                 'max_over_subscription_ratio',
                 CONF.max_over_subscription_ratio)
@@ -523,7 +549,7 @@ class HostManager(object):
 
             # Update capabilities and attributes in host_state
             host_state.update_from_share_capability(
-                capabilities, service=dict(service.items()))
+                capabilities, service=dict(service.items()), context=context)
             active_hosts.add(host)
 
         # remove non-active hosts from host_state_map
