@@ -126,9 +126,12 @@ class SchedulerManager(manager.Manager):
         """Ensure that the host exists and can accept the share."""
 
         def _manage_share_set_error(self, context, ex, request_spec):
+            # NOTE(nidhimittalhada): set size as 1 because design expects size
+            # to be set, it also will allow us to handle delete/unmanage
+            # operations properly with this errored share according to quotas.
             self._set_share_state_and_notify(
                 'manage_share',
-                {'status': constants.STATUS_MANAGE_ERROR},
+                {'status': constants.STATUS_MANAGE_ERROR, 'size': 1},
                 context, ex, request_spec)
 
         share_ref = db.share_get(context, share_id)
@@ -143,33 +146,41 @@ class SchedulerManager(manager.Manager):
             share_rpcapi.ShareAPI().manage_share(context, share_ref,
                                                  driver_options)
 
-    def migrate_share_to_host(self, context, share_id, host,
-                              force_host_copy, notify, request_spec,
-                              filter_properties=None):
+    def migrate_share_to_host(
+            self, context, share_id, host, force_host_assisted_migration,
+            preserve_metadata, writable, nondisruptive, new_share_network_id,
+            new_share_type_id, request_spec, filter_properties=None):
         """Ensure that the host exists and can accept the share."""
 
+        share_ref = db.share_get(context, share_id)
+
         def _migrate_share_set_error(self, context, ex, request_spec):
+            instance = next((x for x in share_ref.instances
+                             if x['status'] == constants.STATUS_MIGRATING),
+                            None)
+            if instance:
+                db.share_instance_update(
+                    context, instance['id'],
+                    {'status': constants.STATUS_AVAILABLE})
             self._set_share_state_and_notify(
                 'migrate_share_to_host',
                 {'task_state': constants.TASK_STATE_MIGRATION_ERROR},
                 context, ex, request_spec)
 
         try:
-            tgt_host = self.driver.host_passes_filters(context, host,
-                                                       request_spec,
-                                                       filter_properties)
+            tgt_host = self.driver.host_passes_filters(
+                context, host, request_spec, filter_properties)
 
-        except exception.NoValidHost as ex:
-            with excutils.save_and_reraise_exception():
-                _migrate_share_set_error(self, context, ex, request_spec)
         except Exception as ex:
             with excutils.save_and_reraise_exception():
                 _migrate_share_set_error(self, context, ex, request_spec)
         else:
-            share_ref = db.share_get(context, share_id)
+
             try:
                 share_rpcapi.ShareAPI().migration_start(
-                    context, share_ref, tgt_host, force_host_copy, notify)
+                    context, share_ref, tgt_host.host,
+                    force_host_assisted_migration, preserve_metadata, writable,
+                    nondisruptive, new_share_network_id, new_share_type_id)
             except Exception as ex:
                 with excutils.save_and_reraise_exception():
                     _migrate_share_set_error(self, context, ex, request_spec)
