@@ -65,7 +65,7 @@ CONF.register_opts(cephfs_native_opts)
 
 
 class CephFSNativeDriver(driver.ShareDriver,):
-    """Driver for the Ceph Filsystem.
+    """Driver for the Ceph Filesystem.
 
     This driver is 'native' in the sense that it exposes a CephFS filesystem
     for use directly by guests, with no intermediate layer like NFS.
@@ -207,14 +207,32 @@ class CephFSNativeDriver(driver.ShareDriver,):
             raise exception.InvalidShareAccess(
                 reason=_("Only 'cephx' access type allowed."))
 
-        if access['access_level'] == constants.ACCESS_LEVEL_RO:
-            raise exception.InvalidShareAccessLevel(
-                level=constants.ACCESS_LEVEL_RO)
-
         ceph_auth_id = access['access_to']
 
-        auth_result = self.volume_client.authorize(self._share_path(share),
-                                                   ceph_auth_id)
+        # We need to check here rather than the API or Manila Client to see
+        # if the ceph_auth_id is the same as the one specified for Manila's
+        # usage. This is due to the fact that the API and the Manila client
+        # cannot read the contents of the Manila configuration file. If it
+        # is the same, we need to error out.
+        if ceph_auth_id == CONF.cephfs_auth_id:
+            error_message = (_('Ceph authentication ID %s must be different '
+                             'than the one the Manila service uses.') %
+                             ceph_auth_id)
+            raise exception.InvalidInput(message=error_message)
+
+        # TODO(rraja): Log the Ceph point release version, once available, in
+        # which the volume client can enable read-only access.
+        if not getattr(self.volume_client, 'version', None):
+            if access['access_level'] == constants.ACCESS_LEVEL_RO:
+                raise exception.InvalidShareAccessLevel(
+                    level=constants.ACCESS_LEVEL_RO)
+            auth_result = self.volume_client.authorize(
+                self._share_path(share), ceph_auth_id)
+        else:
+            readonly = access['access_level'] == constants.ACCESS_LEVEL_RO
+            auth_result = self.volume_client.authorize(
+                self._share_path(share), ceph_auth_id, readonly=readonly,
+                tenant_id=share['project_id'])
 
         return auth_result['auth_key']
 
@@ -227,29 +245,51 @@ class CephFSNativeDriver(driver.ShareDriver,):
 
         self.volume_client.deauthorize(self._share_path(share),
                                        access['access_to'])
-        self.volume_client.evict(access['access_to'])
+        self.volume_client.evict(
+            access['access_to'],
+            volume_path=self._share_path(share))
 
     def update_access(self, context, share, access_rules, add_rules,
                       delete_rules, share_server=None):
-        # The interface to Ceph just provides add/remove methods, since it
-        # was created at start of mitaka cycle when there was no requirement
-        # to be able to list access rules or set them en masse.  Therefore
-        # we implement update_access as best we can.  In future ceph's
-        # interface should be extended to enable a full implementation
-        # of update_access.
+        access_keys = {}
 
+        if not (add_rules or delete_rules):  # recovery/maintenance mode
+            add_rules = access_rules
+
+            existing_auths = None
+
+            # The unversioned volume client cannot fetch from the Ceph backend,
+            # the list of auth IDs that have share access.
+            if getattr(self.volume_client, 'version', None):
+                existing_auths = self.volume_client.get_authorized_ids(
+                    self._share_path(share))
+
+            if existing_auths:
+                existing_auth_ids = set(
+                    [auth[0] for auth in existing_auths])
+                want_auth_ids = set(
+                    [rule['access_to'] for rule in add_rules])
+                delete_auth_ids = existing_auth_ids.difference(
+                    want_auth_ids)
+                for delete_auth_id in delete_auth_ids:
+                    delete_rules.append(
+                        {
+                            'access_to': delete_auth_id,
+                            'access_type': CEPHX_ACCESS_TYPE,
+                        })
+
+        # During recovery mode, re-authorize share access for auth IDs that
+        # were already granted access by the backend. Do this to fetch their
+        # access keys and ensure that after recovery, manila and the Ceph
+        # backend are in sync.
         for rule in add_rules:
-            self._allow_access(context, share, rule)
+            access_key = self._allow_access(context, share, rule)
+            access_keys.update({rule['id']: access_key})
 
         for rule in delete_rules:
             self._deny_access(context, share, rule)
 
-        # This is where we would list all permitted clients and remove
-        # those that are not in `access_rules` if the ceph interface
-        # enabled it.
-        if not (add_rules or delete_rules):
-            for rule in access_rules:
-                self._allow_access(context, share, rule)
+        return access_keys
 
     def delete_share(self, context, share, share_server=None):
         extra_specs = share_types.get_extra_specs_from_share(share)
@@ -287,11 +327,13 @@ class CephFSNativeDriver(driver.ShareDriver,):
 
     def create_snapshot(self, context, snapshot, share_server=None):
         self.volume_client.create_snapshot_volume(
-            self._share_path(snapshot['share']), snapshot['name'])
+            self._share_path(snapshot['share']),
+            '_'.join([snapshot['snapshot_id'], snapshot['id']]))
 
     def delete_snapshot(self, context, snapshot, share_server=None):
         self.volume_client.destroy_snapshot_volume(
-            self._share_path(snapshot['share']), snapshot['name'])
+            self._share_path(snapshot['share']),
+            '_'.join([snapshot['snapshot_id'], snapshot['id']]))
 
     def create_consistency_group(self, context, cg_dict, share_server=None):
         self.volume_client.create_group(cg_dict['id'])
