@@ -24,9 +24,7 @@ from oslo_log import log
 import six
 
 from manila import exception
-from manila.i18n import _
-from manila.i18n import _LE
-from manila.i18n import _LW
+from manila.i18n import _, _LE, _LW
 from manila.share.drivers.ganesha import utils as ganesha_utils
 
 LOG = log.getLogger(__name__)
@@ -61,14 +59,18 @@ def _check_volume_presence(f):
     return wrapper
 
 
-def volxml_get(xmlout, path, *default):
-    """Extract a value by a path from XML."""
-    value = xmlout.find(path)
+def volxml_get(xmlout, *paths, **kwargs):
+    """Attempt to extract a value by a set of Xpaths from XML."""
+    for path in paths:
+        value = xmlout.find(path)
+        if value is not None:
+            break
     if value is None:
-        if default:
-            return default[0]
+        if 'default' in kwargs:
+            return kwargs['default']
         raise exception.InvalidShare(
-            _('Xpath %s not found in volume query response XML') % path)
+            _("Volume query response XML has no value for any of "
+              "the following Xpaths: %s") % ", ".join(paths))
     return value.text
 
 
@@ -225,7 +227,7 @@ class GlusterManager(object):
             ) % {'volume': self.volume, 'command': command})
         if list(six.itervalues(ret)) != [0, 0]:
             errdct = {'volume': self.volume, 'command': commandstr,
-                      'opErrstr': volxml_get(xmlout, 'opErrstr', None)}
+                      'opErrstr': volxml_get(xmlout, 'opErrstr', default=None)}
             errdct.update(ret)
             raise exception.InvalidShare(_(
                 'GlusterFS command %(command)s on volume %(volume)s got '
@@ -289,7 +291,10 @@ class GlusterManager(object):
             return self._get_vol_option_via_info(option)
 
         self.xml_response_check(optxml, args[1:], './volGetopts/count')
-        return volxml_get(optxml, './volGetopts/Value')
+        # the Xpath has changed from first to second as of GlusterFS
+        # 3.7.14 (see http://review.gluster.org/14931).
+        return volxml_get(optxml, './volGetopts/Value',
+                          './volGetopts/Opt/Value')
 
     def get_vol_option(self, option, boolean=False):
         """Get the value of an option set on a GlusterFS volume."""
@@ -377,7 +382,7 @@ def numreduct(vers):
 def _mount_gluster_vol(execute, gluster_export, mount_path, ensure=False):
     """Mount a GlusterFS volume at the specified mount path.
 
-    :param execute: command exectution function
+    :param execute: command execution function
     :param gluster_export: GlusterFS export to mount
     :param mount_path: path to mount at
     :param ensure: boolean to allow remounting a volume with a warning
@@ -398,7 +403,7 @@ def _mount_gluster_vol(execute, gluster_export, mount_path, ensure=False):
 def _umount_gluster_vol(execute, mount_path):
     """Unmount a GlusterFS volume at the specified mount path.
 
-    :param execute: command exectution function
+    :param execute: command execution function
     :param mount_path: path where volume is mounted
     """
 
