@@ -20,8 +20,7 @@ from oslo_log import log
 
 from manila.common import constants as const
 from manila import exception
-from manila.i18n import _
-from manila.i18n import _LW
+from manila.i18n import _, _LW
 from manila import utils
 
 LOG = log.getLogger(__name__)
