@@ -16,6 +16,7 @@
 STATUS_ETH_RUNNING = "10"
 STATUS_FS_HEALTH = "1"
 STATUS_FS_RUNNING = "27"
+STATUS_FSSNAPSHOT_HEALTH = '1'
 STATUS_JOIN_DOMAIN = '1'
 STATUS_EXIT_DOMAIN = '0'
 STATUS_SERVICE_RUNNING = "2"
@@ -45,6 +46,7 @@ ERROR_CONNECT_TO_SERVER = -403
 ERROR_UNAUTHORIZED_TO_SERVER = -401
 ERROR_LOGICAL_PORT_EXIST = 1073813505
 ERROR_USER_OR_GROUP_NOT_EXIST = 1077939723
+ERROR_REPLICATION_PAIR_NOT_EXIST = 1077937923
 
 PORT_TYPE_ETH = '1'
 PORT_TYPE_BOND = '7'
@@ -80,11 +82,13 @@ OPTS_CAPABILITIES = {
     'huawei_smartpartition': False,
     'thin_provisioning': None,
     'qos': False,
+    'huawei_sectorsize': None,
 }
 
 OPTS_VALUE = {
     'cachename': None,
     'partitionname': None,
+    'sectorsize': None,
 }
 
 OPTS_VALUE.update(OPTS_QOS_VALUE)
@@ -92,5 +96,45 @@ OPTS_VALUE.update(OPTS_QOS_VALUE)
 OPTS_ASSOCIATE = {
     'huawei_smartcache': 'cachename',
     'huawei_smartpartition': 'partitionname',
+    'huawei_sectorsize': 'sectorsize',
     'qos': OPTS_QOS_VALUE,
 }
+
+VALID_SECTOR_SIZES = ('4', '8', '16', '32', '64')
+
+LOCAL_RES_TYPES = (FILE_SYSTEM_TYPE,) = ('40',)
+
+REPLICA_MODELS = (REPLICA_SYNC_MODEL,
+                  REPLICA_ASYNC_MODEL) = ('1', '2')
+
+REPLICA_SPEED_MODELS = (REPLICA_SPEED_LOW,
+                        REPLICA_SPEED_MEDIUM,
+                        REPLICA_SPEED_HIGH,
+                        REPLICA_SPEED_HIGHEST) = ('1', '2', '3', '4')
+
+REPLICA_HEALTH_STATUSES = (REPLICA_HEALTH_STATUS_NORMAL,
+                           REPLICA_HEALTH_STATUS_FAULT,
+                           REPLICA_HEALTH_STATUS_INVALID) = ('1', '2', '14')
+
+REPLICA_DATA_STATUSES = (
+    REPLICA_DATA_STATUS_SYNCHRONIZED,
+    REPLICA_DATA_STATUS_COMPLETE,
+    REPLICA_DATA_STATUS_INCOMPLETE) = ('1', '2', '5')
+
+REPLICA_DATA_STATUS_IN_SYNC = (
+    REPLICA_DATA_STATUS_SYNCHRONIZED,
+    REPLICA_DATA_STATUS_COMPLETE)
+
+REPLICA_RUNNING_STATUSES = (
+    REPLICA_RUNNING_STATUS_NORMAL,
+    REPLICA_RUNNING_STATUS_SYNCING,
+    REPLICA_RUNNING_STATUS_SPLITTED,
+    REPLICA_RUNNING_STATUS_TO_RECOVER,
+    REPLICA_RUNNING_STATUS_INTERRUPTED,
+    REPLICA_RUNNING_STATUS_INVALID) = (
+    '1', '23', '26', '33', '34', '35')
+
+REPLICA_SECONDARY_ACCESS_RIGHTS = (
+    REPLICA_SECONDARY_ACCESS_DENIED,
+    REPLICA_SECONDARY_RO,
+    REPLICA_SECONDARY_RW) = ('1', '2', '3')
