@@ -110,6 +110,7 @@ class SmartX(object):
         opts = self.get_smartprovisioning_opts(opts)
         opts = self.get_smartcache_opts(opts)
         opts = self.get_smartpartition_opts(opts)
+        opts = self.get_sectorsize_opts(opts)
         qos = self.get_qos_opts(opts)
         return opts, qos
 
@@ -123,28 +124,11 @@ class SmartX(object):
 
     def get_smartprovisioning_opts(self, opts):
         thin_provision = opts.get('thin_provisioning')
-        if thin_provision is None:
-            root = self.helper._read_xml()
-            fstype = root.findtext('Filesystem/AllocType')
-            if fstype:
-                fstype = fstype.strip().strip('\n')
-                if fstype == 'Thin':
-                    opts['LUNType'] = constants.ALLOC_TYPE_THIN_FLAG
-                elif fstype == 'Thick':
-                    opts['LUNType'] = constants.ALLOC_TYPE_THICK_FLAG
-                else:
-                    err_msg = (_(
-                        'Huawei config file is wrong. AllocType type must be '
-                        'set to "Thin" or "Thick". AllocType:%(fetchtype)s') %
-                        {'fetchtype': fstype})
-                    raise exception.InvalidShare(reason=err_msg)
-            else:
-                opts['LUNType'] = constants.ALLOC_TYPE_THICK_FLAG
+        if (thin_provision is None or
+                strutils.bool_from_string(thin_provision)):
+            opts['LUNType'] = constants.ALLOC_TYPE_THIN_FLAG
         else:
-            if strutils.bool_from_string(thin_provision):
-                opts['LUNType'] = constants.ALLOC_TYPE_THIN_FLAG
-            else:
-                opts['LUNType'] = constants.ALLOC_TYPE_THICK_FLAG
+            opts['LUNType'] = constants.ALLOC_TYPE_THICK_FLAG
 
         return opts
 
@@ -170,6 +154,26 @@ class SmartX(object):
 
         return opts
 
+    def get_sectorsize_opts(self, opts):
+        value = None
+        if strutils.bool_from_string(opts.get('huawei_sectorsize')):
+            value = opts.get('sectorsize')
+        if not value:
+            root = self.helper._read_xml()
+            sectorsize = root.findtext('Filesystem/SectorSize')
+            if sectorsize:
+                sectorsize = sectorsize.strip()
+                value = sectorsize
+
+        if value:
+            if value not in constants.VALID_SECTOR_SIZES:
+                raise exception.InvalidInput(
+                    reason=(_('Illegal value(%s) specified for sectorsize: '
+                              'set to either 4, 8, 16, 32 or 64.') % value))
+            else:
+                opts['sectorsize'] = int(value)
+        return opts
+
     def get_qos_opts(self, opts):
         qos = {}
         if not strutils.bool_from_string(opts.get('qos')):
