@@ -18,6 +18,8 @@ Module with ZFSonLinux share driver that utilizes ZFS filesystem resources
 and exports them as shares.
 """
 
+import math
+import os
 import time
 
 from oslo_config import cfg
@@ -29,8 +31,10 @@ from oslo_utils import timeutils
 from manila.common import constants
 from manila import exception
 from manila.i18n import _, _LI, _LW
+from manila.share import configuration
 from manila.share import driver
 from manila.share.drivers.zfsonlinux import utils as zfs_utils
+from manila.share.manager import share_manager_opts  # noqa
 from manila.share import share_types
 from manila.share import utils as share_utils
 from manila import utils
@@ -108,6 +112,11 @@ zfsonlinux_opts = [
         required=True,
         default="tmp_snapshot_for_replication_",
         help="Set snapshot prefix for usage in ZFS replication. Required."),
+    cfg.StrOpt(
+        "zfs_migration_snapshot_prefix",
+        required=True,
+        default="tmp_snapshot_for_share_migration_",
+        help="Set snapshot prefix for usage in ZFS migration. Required."),
 ]
 
 CONF = cfg.CONF
@@ -118,7 +127,8 @@ LOG = log.getLogger(__name__)
 def ensure_share_server_not_provided(f):
 
     def wrap(self, context, *args, **kwargs):
-        server = kwargs.get('share_server')
+        server = kwargs.get(
+            "share_server", kwargs.get("destination_share_server"))
         if server:
             raise exception.InvalidInput(
                 reason=_("Share server handling is not available. "
@@ -130,6 +140,27 @@ def ensure_share_server_not_provided(f):
     return wrap
 
 
+def get_backend_configuration(backend_name):
+    config_stanzas = CONF.list_all_sections()
+    if backend_name not in config_stanzas:
+        msg = _("Could not find backend stanza %(backend_name)s in "
+                "configuration which is required for share replication and "
+                "migration. Available stanzas are %(stanzas)s")
+        params = {
+            "stanzas": config_stanzas,
+            "backend_name": backend_name,
+        }
+        raise exception.BadConfigurationException(reason=msg % params)
+
+    config = configuration.Configuration(
+        driver.share_opts, config_group=backend_name)
+    config.append_config_values(zfsonlinux_opts)
+    config.append_config_values(share_manager_opts)
+    config.append_config_values(driver.ssh_opts)
+
+    return config
+
+
 class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     def __init__(self, *args, **kwargs):
@@ -137,6 +168,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             [False], *args, config_opts=[zfsonlinux_opts], **kwargs)
         self.replica_snapshot_prefix = (
             self.configuration.zfs_replica_snapshot_prefix)
+        self.migration_snapshot_prefix = (
+            self.configuration.zfs_migration_snapshot_prefix)
         self.backend_name = self.configuration.safe_get(
             'share_backend_name') or 'ZFSonLinux'
         self.zpool_list = self._get_zpool_list()
@@ -150,6 +183,29 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
         # Set config based capabilities
         self._init_common_capabilities()
 
+        self._shell_executors = {}
+
+    def _get_shell_executor_by_host(self, host):
+        backend_name = share_utils.extract_host(host, level='backend_name')
+        if backend_name in CONF.enabled_share_backends:
+            # Return executor of this host
+            return self.execute
+        elif backend_name not in self._shell_executors:
+            config = get_backend_configuration(backend_name)
+            self._shell_executors[backend_name] = (
+                zfs_utils.get_remote_shell_executor(
+                    ip=config.zfs_service_ip,
+                    port=22,
+                    conn_timeout=config.ssh_conn_timeout,
+                    login=config.zfs_ssh_username,
+                    password=config.zfs_ssh_user_password,
+                    privatekey=config.zfs_ssh_private_key_path,
+                    max_size=10,
+                )
+            )
+        # Return executor of remote host
+        return self._shell_executors[backend_name]
+
     def _init_common_capabilities(self):
         self.common_capabilities = {}
         if 'dedup=on' in self.dataset_creation_options:
@@ -431,7 +487,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             share['id'], {
                 'entity_type': 'share',
                 'dataset_name': dataset_name,
-                'ssh_cmd': ssh_cmd,  # used in replication
+                'ssh_cmd': ssh_cmd,  # used with replication and migration
                 'pool_name': pool_name,  # used in replication
                 'used_options': ' '.join(options),
             }
@@ -446,6 +502,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
     def delete_share(self, context, share, share_server=None):
         """Is called to remove a share."""
         pool_name = self.private_storage.get(share['id'], 'pool_name')
+        pool_name = pool_name or share_utils.extract_host(
+            share["host"], level="pool")
         dataset_name = self.private_storage.get(share['id'], 'dataset_name')
         if not dataset_name:
             dataset_name = self._get_dataset_name(share)
@@ -460,7 +518,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             out, err = self.zfs('list', '-r', '-t', 'snapshot', pool_name)
             snapshots = self.parse_zfs_answer(out)
             full_snapshot_prefix = (
-                dataset_name + '@' + self.replica_snapshot_prefix)
+                dataset_name + '@')
             for snap in snapshots:
                 if full_snapshot_prefix in snap['NAME']:
                     self._delete_dataset_or_snapshot_with_retry(snap['NAME'])
@@ -490,11 +548,13 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             }
         )
         self.zfs('snapshot', snapshot_name)
+        return {"provider_location": snapshot_name}
 
     @ensure_share_server_not_provided
     def delete_snapshot(self, context, snapshot, share_server=None):
         """Is called to remove a snapshot."""
-        return self._delete_snapshot(context, snapshot)
+        self._delete_snapshot(context, snapshot)
+        self.private_storage.delete(snapshot['snapshot_id'])
 
     def _get_saved_snapshot_name(self, snapshot_instance):
         snapshot_tag = self.private_storage.get(
@@ -517,7 +577,6 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 _LW("Snapshot with '%(id)s' ID and '%(name)s' NAME is "
                     "absent on backend. Nothing has been deleted."),
                 {'id': snapshot['id'], 'name': snapshot_name})
-        self.private_storage.delete(snapshot['id'])
 
     @ensure_share_server_not_provided
     def create_share_from_snapshot(self, context, share, snapshot,
@@ -622,13 +681,155 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                       delete_rules, share_server=None):
         """Updates access rules for given share."""
         dataset_name = self._get_dataset_name(share)
+        executor = self._get_shell_executor_by_host(share['host'])
         return self._get_share_helper(share['share_proto']).update_access(
-            dataset_name, access_rules, add_rules, delete_rules)
+            dataset_name, access_rules, add_rules, delete_rules,
+            executor=executor)
+
+    def manage_existing(self, share, driver_options):
+        """Manage existing ZFS dataset as manila share.
+
+        ZFSonLinux driver accepts only one driver_option 'size'.
+        If an administrator provides this option, then such quota will be set
+        to dataset and used as share size. Otherwise, driver will set quota
+        equal to nearest bigger rounded integer of usage size.
+        Driver does not expect mountpoint to be changed (should be equal
+        to default that is "/%(dataset_name)s").
+
+        :param share: share data
+        :param driver_options: Empty dict or dict with 'size' option.
+        :return: dict with share size and its export locations.
+        """
+        old_export_location = share["export_locations"][0]["path"]
+        old_dataset_name = old_export_location.split(":/")[-1]
+
+        scheduled_pool_name = share_utils.extract_host(
+            share["host"], level="pool")
+        actual_pool_name = old_dataset_name.split("/")[0]
+
+        new_dataset_name = self._get_dataset_name(share)
+
+        # Calculate quota for managed dataset
+        quota = driver_options.get("size")
+        if not quota:
+            consumed_space = self.get_zfs_option(old_dataset_name, "used")
+            consumed_space = utils.translate_string_size_to_float(
+                consumed_space)
+            quota = int(consumed_space) + 1
+        share["size"] = int(quota)
+
+        # Save dataset-specific data in private storage
+        options = self._get_dataset_creation_options(share, is_readonly=False)
+        ssh_cmd = "%(username)s@%(host)s" % {
+            "username": self.configuration.zfs_ssh_username,
+            "host": self.service_ip,
+        }
+        self.private_storage.update(
+            share["id"], {
+                "entity_type": "share",
+                "dataset_name": new_dataset_name,
+                "ssh_cmd": ssh_cmd,  # used in replication
+                "pool_name": actual_pool_name,  # used in replication
+                "used_options": " ".join(options),
+            }
+        )
+
+        # Perform checks on requested dataset
+        if actual_pool_name != scheduled_pool_name:
+            raise exception.ZFSonLinuxException(
+                _("Cannot manage share '%(share_id)s' "
+                  "(share_instance '%(si_id)s'), because scheduled "
+                  "pool '%(sch)s' and actual '%(actual)s' differ.") % {
+                    "share_id": share["share_id"],
+                    "si_id": share["id"],
+                    "sch": scheduled_pool_name,
+                    "actual": actual_pool_name})
+
+        out, err = self.zfs("list", "-r", actual_pool_name)
+        data = self.parse_zfs_answer(out)
+        for datum in data:
+            if datum["NAME"] == old_dataset_name:
+                break
+        else:
+            raise exception.ZFSonLinuxException(
+                _("Cannot manage share '%(share_id)s' "
+                  "(share_instance '%(si_id)s'), because dataset "
+                  "'%(dataset)s' not found in zpool '%(zpool)s'.") % {
+                    "share_id": share["share_id"],
+                    "si_id": share["id"],
+                    "dataset": old_dataset_name,
+                    "zpool": actual_pool_name})
+
+        # Rename dataset
+        out, err = self.execute("sudo", "mount")
+        if "%s " % old_dataset_name in out:
+            self.zfs_with_retry("umount", "-f", old_dataset_name)
+            time.sleep(1)
+        self.zfs_with_retry("rename", old_dataset_name, new_dataset_name)
+        self.zfs("mount", new_dataset_name)
+
+        # Apply options to dataset
+        for option in options:
+            self.zfs("set", option, new_dataset_name)
+
+        # Get new export locations of renamed dataset
+        export_locations = self._get_share_helper(
+            share["share_proto"]).get_exports(new_dataset_name)
+
+        return {"size": share["size"], "export_locations": export_locations}
 
     def unmanage(self, share):
         """Removes the specified share from Manila management."""
         self.private_storage.delete(share['id'])
 
+    def manage_existing_snapshot(self, snapshot_instance, driver_options):
+        """Manage existing share snapshot with manila.
+
+        :param snapshot_instance: SnapshotInstance data
+        :param driver_options: expects only one optional key 'size'.
+        :return: dict with share snapshot instance fields for update, example:
+            {'size': 1,
+             'provider_location': 'path/to/some/dataset@some_snapshot_tag'}
+        """
+        snapshot_size = int(driver_options.get("size", 0))
+        old_provider_location = snapshot_instance.get("provider_location")
+        old_snapshot_tag = old_provider_location.split("@")[-1]
+        new_snapshot_tag = self._get_snapshot_name(snapshot_instance["id"])
+
+        self.private_storage.update(
+            snapshot_instance["snapshot_id"], {
+                "entity_type": "snapshot",
+                "old_snapshot_tag": old_snapshot_tag,
+                "snapshot_tag": new_snapshot_tag,
+            }
+        )
+
+        try:
+            self.zfs("list", "-r", "-t", "snapshot", old_provider_location)
+        except exception.ProcessExecutionError as e:
+            raise exception.ManageInvalidShareSnapshot(reason=e.stderr)
+
+        if not snapshot_size:
+            consumed_space = self.get_zfs_option(old_provider_location, "used")
+            consumed_space = utils.translate_string_size_to_float(
+                consumed_space)
+            snapshot_size = int(math.ceil(consumed_space))
+
+        dataset_name = self.private_storage.get(
+            snapshot_instance["share_instance_id"], "dataset_name")
+        new_provider_location = dataset_name + "@" + new_snapshot_tag
+
+        self.zfs("rename", old_provider_location, new_provider_location)
+
+        return {
+            "size": snapshot_size,
+            "provider_location": new_provider_location,
+        }
+
+    def unmanage_snapshot(self, snapshot_instance):
+        """Unmanage dataset snapshot."""
+        self.private_storage.delete(snapshot_instance["snapshot_id"])
+
     def _get_replication_snapshot_prefix(self, replica):
         """Returns replica-based snapshot prefix."""
         replication_snapshot_prefix = "%s_%s" % (
@@ -649,6 +850,22 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
         msg = _("Active replica not found.")
         raise exception.ReplicationException(reason=msg)
 
+    def _get_migration_snapshot_prefix(self, share_instance):
+        """Returns migration-based snapshot prefix."""
+        migration_snapshot_prefix = "%s_%s" % (
+            self.migration_snapshot_prefix,
+            share_instance['id'].replace('-', '_'))
+        return migration_snapshot_prefix
+
+    def _get_migration_snapshot_tag(self, share_instance):
+        """Returns migration- and time-based snapshot tag."""
+        current_time = timeutils.utcnow().isoformat()
+        snapshot_tag = "%s_time_%s" % (
+            self._get_migration_snapshot_prefix(share_instance), current_time)
+        snapshot_tag = (
+            snapshot_tag.replace('-', '_').replace('.', '_').replace(':', '_'))
+        return snapshot_tag
+
     @ensure_share_server_not_provided
     def create_replica(self, context, replica_list, new_replica,
                        access_rules, replica_snapshots, share_server=None):
@@ -1108,6 +1325,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             replica_snapshots_dict[replica_snapshot['id']]['status'] = (
                 constants.STATUS_DELETED)
 
+        self.private_storage.delete(replica_snapshot['snapshot_id'])
         return list(replica_snapshots_dict.values())
 
     @ensure_share_server_not_provided
@@ -1134,3 +1352,193 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             return_dict.update({'status': constants.STATUS_ERROR})
 
         return return_dict
+
+    @ensure_share_server_not_provided
+    def migration_check_compatibility(
+            self, context, source_share, destination_share,
+            share_server=None, destination_share_server=None):
+        """Is called to test compatibility with destination backend."""
+        backend_name = share_utils.extract_host(
+            destination_share['host'], level='backend_name')
+        config = get_backend_configuration(backend_name)
+        compatible = self.configuration.share_driver == config.share_driver
+        return {
+            'compatible': compatible,
+            'writable': False,
+            'preserve_metadata': True,
+            'nondisruptive': True,
+        }
+
+    @ensure_share_server_not_provided
+    def migration_start(
+            self, context, source_share, destination_share,
+            share_server=None, destination_share_server=None):
+        """Is called to start share migration."""
+
+        src_dataset_name = self.private_storage.get(
+            source_share['id'], 'dataset_name')
+        dst_dataset_name = self._get_dataset_name(destination_share)
+        backend_name = share_utils.extract_host(
+            destination_share['host'], level='backend_name')
+        ssh_cmd = '%(username)s@%(host)s' % {
+            'username': self.configuration.zfs_ssh_username,
+            'host': self.configuration.zfs_service_ip,
+        }
+        config = get_backend_configuration(backend_name)
+        remote_ssh_cmd = '%(username)s@%(host)s' % {
+            'username': config.zfs_ssh_username,
+            'host': config.zfs_service_ip,
+        }
+        snapshot_tag = self._get_migration_snapshot_tag(destination_share)
+        src_snapshot_name = (
+            '%(dataset_name)s@%(snapshot_tag)s' % {
+                'snapshot_tag': snapshot_tag,
+                'dataset_name': src_dataset_name,
+            }
+        )
+
+        # Save valuable data to DB
+        self.private_storage.update(source_share['id'], {
+            'migr_snapshot_tag': snapshot_tag,
+        })
+        self.private_storage.update(destination_share['id'], {
+            'entity_type': 'share',
+            'dataset_name': dst_dataset_name,
+            'ssh_cmd': remote_ssh_cmd,
+            'pool_name': share_utils.extract_host(
+                destination_share['host'], level='pool'),
+            'migr_snapshot_tag': snapshot_tag,
+        })
+
+        # Create temporary snapshot on src host.
+        self.execute('sudo', 'zfs', 'snapshot', src_snapshot_name)
+
+        # Send/receive temporary snapshot
+        cmd = (
+            'ssh ' + ssh_cmd + ' '
+            'sudo zfs send -vDR ' + src_snapshot_name + ' '
+            '| ssh ' + remote_ssh_cmd + ' '
+            'sudo zfs receive -v ' + dst_dataset_name
+        )
+        filename = dst_dataset_name.replace('/', '_')
+        with utils.tempdir() as tmpdir:
+            tmpfilename = os.path.join(tmpdir, '%s.sh' % filename)
+            with open(tmpfilename, "w") as migr_script:
+                migr_script.write(cmd)
+            self.execute('sudo', 'chmod', '755', tmpfilename)
+            self.execute('nohup', tmpfilename, '&')
+
+    @ensure_share_server_not_provided
+    def migration_continue(
+            self, context, source_share, destination_share,
+            share_server=None, destination_share_server=None):
+        """Is called in source share's backend to continue migration."""
+
+        snapshot_tag = self.private_storage.get(
+            destination_share['id'], 'migr_snapshot_tag')
+
+        out, err = self.execute('ps', 'aux')
+        if not '@%s' % snapshot_tag in out:
+            dst_dataset_name = self.private_storage.get(
+                destination_share['id'], 'dataset_name')
+            try:
+                self.execute(
+                    'sudo', 'zfs', 'get', 'quota', dst_dataset_name,
+                    executor=self._get_shell_executor_by_host(
+                        destination_share['host']),
+                )
+                return True
+            except exception.ProcessExecutionError as e:
+                raise exception.ZFSonLinuxException(msg=_(
+                    'Migration process is absent and dst dataset '
+                    'returned following error: %s') % e)
+
+    @ensure_share_server_not_provided
+    def migration_complete(
+            self, context, source_share, destination_share,
+            share_server=None, destination_share_server=None):
+        """Is called to perform 2nd phase of driver migration of a given share.
+
+        """
+        dst_dataset_name = self.private_storage.get(
+            destination_share['id'], 'dataset_name')
+        snapshot_tag = self.private_storage.get(
+            destination_share['id'], 'migr_snapshot_tag')
+        dst_snapshot_name = (
+            '%(dataset_name)s@%(snapshot_tag)s' % {
+                'snapshot_tag': snapshot_tag,
+                'dataset_name': dst_dataset_name,
+            }
+        )
+
+        dst_executor = self._get_shell_executor_by_host(
+            destination_share['host'])
+
+        # Destroy temporary migration snapshot on dst host
+        self.execute(
+            'sudo', 'zfs', 'destroy', dst_snapshot_name,
+            executor=dst_executor,
+        )
+
+        # Get export locations of new share instance
+        export_locations = self._get_share_helper(
+            destination_share['share_proto']).create_exports(
+                dst_dataset_name,
+                executor=dst_executor)
+
+        # Destroy src share and temporary migration snapshot on src (this) host
+        self.delete_share(context, source_share)
+
+        return export_locations
+
+    @ensure_share_server_not_provided
+    def migration_cancel(
+            self, context, source_share, destination_share,
+            share_server=None, destination_share_server=None):
+        """Is called to cancel driver migration."""
+
+        src_dataset_name = self.private_storage.get(
+            source_share['id'], 'dataset_name')
+        dst_dataset_name = self.private_storage.get(
+            destination_share['id'], 'dataset_name')
+        ssh_cmd = self.private_storage.get(
+            destination_share['id'], 'ssh_cmd')
+        snapshot_tag = self.private_storage.get(
+            destination_share['id'], 'migr_snapshot_tag')
+
+        # Kill migration process if exists
+        try:
+            out, err = self.execute('ps', 'aux')
+            lines = out.split('\n')
+            for line in lines:
+                if '@%s' % snapshot_tag in line:
+                    migr_pid = [
+                        x for x in line.strip().split(' ') if x != ''][1]
+                    self.execute('sudo', 'kill', '-9', migr_pid)
+        except exception.ProcessExecutionError as e:
+            LOG.warning(_LW(
+                "Caught following error trying to kill migration process: %s"),
+                e)
+
+        # Sleep couple of seconds before destroying updated objects
+        time.sleep(2)
+
+        # Destroy snapshot on source host
+        self._delete_dataset_or_snapshot_with_retry(
+            src_dataset_name + '@' + snapshot_tag)
+
+        # Destroy dataset and its migration snapshot on destination host
+        try:
+            self.execute(
+                'ssh', ssh_cmd,
+                'sudo', 'zfs', 'destroy', '-r', dst_dataset_name,
+            )
+        except exception.ProcessExecutionError as e:
+            LOG.warning(_LW(
+                "Failed to destroy destination dataset with following error: "
+                "%s"),
+                e)
+
+        LOG.debug(
+            "Migration of share with ID '%s' has been canceled." %
+            source_share["id"])
