@@ -212,7 +212,7 @@ class FakeHostManager(host_manager.HostManager):
                       'allocated_capacity_gb': 256,
                       'provisioned_capacity_gb': 256,
                       'max_over_subscription_ratio': 2.0,
-                      'thin_provisioning': False,
+                      'thin_provisioning': [False],
                       'consistency_group_support': 'host',
                       'reserved_percentage': 0,
                       'snapshot_support': True,
@@ -223,7 +223,7 @@ class FakeHostManager(host_manager.HostManager):
                       'allocated_capacity_gb': 1848,
                       'provisioned_capacity_gb': 1848,
                       'max_over_subscription_ratio': 1.0,
-                      'thin_provisioning': True,
+                      'thin_provisioning': [True],
                       'reserved_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
@@ -235,7 +235,7 @@ class FakeHostManager(host_manager.HostManager):
                       'allocated_capacity_gb': 1548,
                       'provisioned_capacity_gb': 1548,
                       'max_over_subscription_ratio': 1.5,
-                      'thin_provisioning': True,
+                      'thin_provisioning': [True, False],
                       'reserved_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
