@@ -49,7 +49,7 @@ class ShareRpcAPITestCase(test.TestCase):
         share_server = db_utils.create_share_server()
         cg = {'id': 'fake_cg_id', 'host': 'fake_host'}
         cgsnapshot = {'id': 'fake_cg_id'}
-        host = {'host': 'fake_host', 'capabilities': 1}
+        host = 'fake_host'
         self.fake_share = jsonutils.to_primitive(share)
         # mock out the getattr on the share db model object since jsonutils
         # doesn't know about those extra attributes to pull in
@@ -74,7 +74,7 @@ class ShareRpcAPITestCase(test.TestCase):
             "version": kwargs.pop('version', self.rpcapi.BASE_RPC_API_VERSION)
         }
         expected_msg = copy.deepcopy(kwargs)
-        if 'share' in expected_msg and method != 'get_migration_info':
+        if 'share' in expected_msg and method != 'get_connection_info':
             share = expected_msg['share']
             del expected_msg['share']
             expected_msg['share_id'] = share['id']
@@ -101,7 +101,7 @@ class ShareRpcAPITestCase(test.TestCase):
             expected_msg['snapshot_id'] = snapshot['id']
         if 'dest_host' in expected_msg:
             del expected_msg['dest_host']
-            expected_msg['host'] = self.fake_host
+            expected_msg['dest_host'] = self.fake_host
         if 'share_replica' in expected_msg:
             share_replica = expected_msg.pop('share_replica', None)
             expected_msg['share_replica_id'] = share_replica['id']
@@ -110,6 +110,9 @@ class ShareRpcAPITestCase(test.TestCase):
             snapshot = expected_msg.pop('replicated_snapshot', None)
             expected_msg['snapshot_id'] = snapshot['id']
             expected_msg['share_id'] = snapshot['share_id']
+        if 'src_share_instance' in expected_msg:
+            share_instance = expected_msg.pop('src_share_instance', None)
+            expected_msg['src_instance_id'] = share_instance['id']
 
         if 'host' in kwargs:
             host = kwargs['host']
@@ -123,8 +126,10 @@ class ShareRpcAPITestCase(test.TestCase):
             host = kwargs['share_replica']['host']
         elif 'replicated_snapshot' in kwargs:
             host = kwargs['share']['instance']['host']
-        else:
+        elif 'share' in kwargs:
             host = kwargs['share']['host']
+        else:
+            host = self.fake_host
         target['server'] = host
         target['topic'] = '%s.%s' % (CONF.share_topic, host)
 
@@ -196,7 +201,8 @@ class ShareRpcAPITestCase(test.TestCase):
         self._test_share_api('delete_snapshot',
                              rpc_method='cast',
                              snapshot=self.fake_snapshot,
-                             host='fake_host')
+                             host='fake_host',
+                             force=False)
 
     def test_delete_share_server(self):
         self._test_share_api('delete_share_server',
@@ -246,46 +252,44 @@ class ShareRpcAPITestCase(test.TestCase):
                              host='fake_host1')
 
     def test_migration_start(self):
-        fake_dest_host = self.Desthost()
         self._test_share_api('migration_start',
                              rpc_method='cast',
-                             version='1.6',
+                             version='1.12',
                              share=self.fake_share,
-                             dest_host=fake_dest_host,
-                             force_host_copy=True,
-                             notify=True)
+                             dest_host=self.fake_host,
+                             force_host_assisted_migration=True,
+                             preserve_metadata=True,
+                             writable=True,
+                             nondisruptive=False,
+                             new_share_network_id='fake_net_id',
+                             new_share_type_id='fake_type_id')
 
-    def test_migration_get_info(self):
-        self._test_share_api('migration_get_info',
+    def test_connection_get_info(self):
+        self._test_share_api('connection_get_info',
                              rpc_method='call',
-                             version='1.6',
-                             share_instance=self.fake_share)
-
-    def test_migration_get_driver_info(self):
-        self._test_share_api('migration_get_driver_info',
-                             rpc_method='call',
-                             version='1.6',
+                             version='1.12',
                              share_instance=self.fake_share)
 
     def test_migration_complete(self):
         self._test_share_api('migration_complete',
                              rpc_method='cast',
-                             version='1.10',
-                             share=self.fake_share,
-                             share_instance_id='fake_ins_id',
-                             new_share_instance_id='new_fake_ins_id')
+                             version='1.12',
+                             src_share_instance=self.fake_share['instance'],
+                             dest_instance_id='new_fake_ins_id')
 
     def test_migration_cancel(self):
         self._test_share_api('migration_cancel',
-                             rpc_method='call',
-                             version='1.10',
-                             share=self.fake_share)
+                             rpc_method='cast',
+                             version='1.12',
+                             src_share_instance=self.fake_share['instance'],
+                             dest_instance_id='ins2_id')
 
     def test_migration_get_progress(self):
         self._test_share_api('migration_get_progress',
                              rpc_method='call',
-                             version='1.10',
-                             share=self.fake_share)
+                             version='1.12',
+                             src_share_instance=self.fake_share['instance'],
+                             dest_instance_id='ins2_id')
 
     def test_delete_share_replica(self):
         self._test_share_api('delete_share_replica',
@@ -337,6 +341,17 @@ class ShareRpcAPITestCase(test.TestCase):
                              force=False,
                              host='fake_host')
 
-    class Desthost(object):
-        host = 'fake_host'
-        capabilities = 1
+    def test_provide_share_server(self):
+        self._test_share_api('provide_share_server',
+                             rpc_method='call',
+                             version='1.12',
+                             share_instance=self.fake_share['instance'],
+                             share_network_id='fake_network_id',
+                             snapshot_id='fake_snapshot_id')
+
+    def test_create_share_server(self):
+        self._test_share_api('create_share_server',
+                             rpc_method='cast',
+                             version='1.12',
+                             share_instance=self.fake_share['instance'],
+                             share_server_id='fake_server_id')
