@@ -13,10 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest import config  # noqa
-from tempest import test  # noqa
+from tempest import config
+from tempest import test
 
-from manila_tempest_tests import clients_share as clients
 from manila_tempest_tests.tests.api import base
 
 CONF = config.CONF
@@ -29,12 +28,11 @@ class SharesAdminQuotasTest(base.BaseSharesAdminTest):
         if not CONF.share.run_quota_tests:
             msg = "Quota tests are disabled."
             raise cls.skipException(msg)
-        cls.os = clients.AdminManager()
         super(SharesAdminQuotasTest, cls).resource_setup()
         cls.user_id = cls.shares_v2_client.user_id
         cls.tenant_id = cls.shares_v2_client.tenant_id
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_default_quotas(self):
         quotas = self.shares_v2_client.default_quotas(self.tenant_id)
         self.assertGreater(int(quotas["gigabytes"]), -2)
@@ -43,7 +41,7 @@ class SharesAdminQuotasTest(base.BaseSharesAdminTest):
         self.assertGreater(int(quotas["snapshots"]), -2)
         self.assertGreater(int(quotas["share_networks"]), -2)
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_show_quotas(self):
         quotas = self.shares_v2_client.show_quotas(self.tenant_id)
         self.assertGreater(int(quotas["gigabytes"]), -2)
@@ -52,7 +50,7 @@ class SharesAdminQuotasTest(base.BaseSharesAdminTest):
         self.assertGreater(int(quotas["snapshots"]), -2)
         self.assertGreater(int(quotas["share_networks"]), -2)
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_show_quotas_for_user(self):
         quotas = self.shares_v2_client.show_quotas(
             self.tenant_id, self.user_id)
@@ -73,7 +71,6 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
         if not CONF.share.run_quota_tests:
             msg = "Quota tests are disabled."
             raise cls.skipException(msg)
-        cls.os = clients.AdminManager()
         super(SharesAdminQuotasUpdateTest, cls).resource_setup()
 
     def setUp(self):
@@ -83,7 +80,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
         self.tenant_id = self.client.tenant_id
         self.user_id = self.client.user_id
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_tenant_quota_shares(self):
         # get current quotas
         quotas = self.client.show_quotas(self.tenant_id)
@@ -93,7 +90,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
         updated = self.client.update_quotas(self.tenant_id, shares=new_quota)
         self.assertEqual(new_quota, int(updated["shares"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_user_quota_shares(self):
         # get current quotas
         quotas = self.client.show_quotas(self.tenant_id, self.user_id)
@@ -104,7 +101,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             self.tenant_id, self.user_id, shares=new_quota)
         self.assertEqual(new_quota, int(updated["shares"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_tenant_quota_snapshots(self):
         # get current quotas
         quotas = self.client.show_quotas(self.tenant_id)
@@ -115,7 +112,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             self.tenant_id, snapshots=new_quota)
         self.assertEqual(new_quota, int(updated["snapshots"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_user_quota_snapshots(self):
         # get current quotas
         quotas = self.client.show_quotas(self.tenant_id, self.user_id)
@@ -126,7 +123,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             self.tenant_id, self.user_id, snapshots=new_quota)
         self.assertEqual(new_quota, int(updated["snapshots"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_tenant_quota_gigabytes(self):
         # get current quotas
         custom = self.client.show_quotas(self.tenant_id)
@@ -139,7 +136,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             self.tenant_id, gigabytes=gigabytes)
         self.assertEqual(gigabytes, int(updated["gigabytes"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_tenant_quota_snapshot_gigabytes(self):
         # get current quotas
         custom = self.client.show_quotas(self.tenant_id)
@@ -154,7 +151,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
         self.assertEqual(snapshot_gigabytes,
                          int(updated["snapshot_gigabytes"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_user_quota_gigabytes(self):
         # get current quotas
         custom = self.client.show_quotas(self.tenant_id, self.user_id)
@@ -167,7 +164,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             self.tenant_id, self.user_id, gigabytes=gigabytes)
         self.assertEqual(gigabytes, int(updated["gigabytes"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_user_quota_snapshot_gigabytes(self):
         # get current quotas
         custom = self.client.show_quotas(self.tenant_id, self.user_id)
@@ -182,7 +179,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
         self.assertEqual(snapshot_gigabytes,
                          int(updated["snapshot_gigabytes"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_tenant_quota_share_networks(self):
         # get current quotas
         quotas = self.client.show_quotas(self.tenant_id)
@@ -193,7 +190,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             self.tenant_id, share_networks=new_quota)
         self.assertEqual(new_quota, int(updated["share_networks"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_update_user_quota_share_networks(self):
         # get current quotas
         quotas = self.client.show_quotas(
@@ -206,7 +203,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
             share_networks=new_quota)
         self.assertEqual(new_quota, int(updated["share_networks"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_reset_tenant_quotas(self):
         # get default_quotas
         default = self.client.default_quotas(self.tenant_id)
@@ -247,7 +244,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
         self.assertEqual(int(default["share_networks"]),
                          int(reseted["share_networks"]))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_quota_for_shares(self):
         self.client.update_quotas(self.tenant_id, shares=-1)
 
@@ -255,7 +252,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('shares'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_user_quota_for_shares(self):
         self.client.update_quotas(
             self.tenant_id, self.user_id, shares=-1)
@@ -264,7 +261,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('shares'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_quota_for_snapshots(self):
         self.client.update_quotas(self.tenant_id, snapshots=-1)
 
@@ -272,7 +269,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('snapshots'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_user_quota_for_snapshots(self):
         self.client.update_quotas(
             self.tenant_id, self.user_id, snapshots=-1)
@@ -281,7 +278,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('snapshots'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_quota_for_gigabytes(self):
         self.client.update_quotas(self.tenant_id, gigabytes=-1)
 
@@ -289,7 +286,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('gigabytes'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_quota_for_snapshot_gigabytes(self):
         self.client.update_quotas(
             self.tenant_id, snapshot_gigabytes=-1)
@@ -298,7 +295,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('snapshot_gigabytes'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_user_quota_for_gigabytes(self):
         self.client.update_quotas(
             self.tenant_id, self.user_id, gigabytes=-1)
@@ -307,7 +304,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('gigabytes'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_user_quota_for_snapshot_gigabytes(self):
         self.client.update_quotas(
             self.tenant_id, self.user_id, snapshot_gigabytes=-1)
@@ -316,7 +313,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('snapshot_gigabytes'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_quota_for_share_networks(self):
         self.client.update_quotas(self.tenant_id, share_networks=-1)
 
@@ -324,7 +321,7 @@ class SharesAdminQuotasUpdateTest(base.BaseSharesAdminTest):
 
         self.assertEqual(-1, quotas.get('share_networks'))
 
-    @test.attr(type=["gate", "smoke", ])
+    @test.attr(type=[base.TAG_POSITIVE, base.TAG_API])
     def test_unlimited_user_quota_for_share_networks(self):
         self.client.update_quotas(
             self.tenant_id, self.user_id, share_networks=-1)
